;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "ebib" "20250909.1036"
  "A BibTeX database manager."
  '((parsebib "6.0")
    (emacs    "27.1")
    (compat   "29.1.4.3"))
  :url "http://joostkremers.github.io/ebib/"
  :commit "72686b4d045dcbdb794e56c8ba60a77eed52ee83"
  :revdesc "72686b4d045d"
  :keywords '("text" "bibtex")
  :authors '(("Joost Kremers" . "joostkremers@fastmail.fm"))
  :maintainers '(("Joost Kremers" . "joostkremers@fastmail.fm")))
